Module weak

Module weak 

feature = "experimental-weak" Weak linking emulation. See crate docs for info.

Structs

ApiUnsupported
Error indicating that we failed to load the API.
ULockApi
A dynamically loaded pair of function pointers implementing the API.

Functions

ulock_wait
Equivalent to __ulock_wait, but lazy-loads and returns Err(ApiUnsupported) if this machine doesn’t support the API.
ulock_wake
Equivalent to __ulock_wake, but lazy-loads and returns Err(ApiUnsupported) if this machine doesn’t support the API.