feature = "experimental-weak" Weak linking emulation. See crate docs for info.
Structs
- ApiUnsupported
- Error indicating that we failed to load the API.
- ULock
Api - A dynamically loaded pair of function pointers implementing the API.
Functions
- ulock_
wait ⚠ - Equivalent to
__ulock_wait, but lazy-loads and returnsErr(ApiUnsupported)if this machine doesn’t support the API. - ulock_
wake ⚠ - Equivalent to
__ulock_wake, but lazy-loads and returnsErr(ApiUnsupported)if this machine doesn’t support the API.